==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/utilifor/utinit.f <==
      SUBROUTINE UTINIT ( NBFICA , MCOL , ITB )
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF UTILIFOR  DATE 10/12/2001   AUTEUR VABHHTS J.PELLET 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR   
C (AT YOUR OPTION) ANY LATER VERSION.                                 
C
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT 
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF          
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU    
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                            
C
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE   
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,       
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.      
C ======================================================================
      IMPLICIT REAL*8 (A-H,O-Z)
      INTEGER             NBFICA , MCOL , ITB
C
      INTEGER          MXUNIT     , MXNUML
      PARAMETER      ( MXUNIT = 7 , MXNUML = 4 )
      INTEGER          UNIT(MXUNIT,MXNUML), NBUNIT(MXUNIT)
      COMMON /UTINIF/  UNIT               , NBUNIT
      INTEGER          MXCOLS , ITABU , LIGCOU , COLCOU , IDF
      COMMON /UTINIP/  MXCOLS , ITABU , LIGCOU , COLCOU , IDF
      INTEGER          LDEB
      COMMON /UTDEB /  LDEB
C     COMPTEUR D'ERREURS POUR POUVOIR ARRETER EN F S'IL N'Y A QUE DES E
      INTEGER          NBERRF,NBERRE
      COMMON /UTNBER/  NBERRF,NBERRE
C     ------------------------------------------------------------------
      DO 100 K = 1,MXUNIT
      NBUNIT(K) = 0
      DO 100 L = 1,MXNUML
      UNIT(K,L) = 0
 100  CONTINUE
      LDEB = 5

      NBERRF=0
      NBERRE=0

C     REDIRECTION DES MESSAGES D'ERREUR E
C
      NBUNIT(1) = 3
      UNIT(1,1) = IUNIFI('ERREUR')
      UNIT(1,2) = IUNIFI('MESSAGE')
      UNIT(1,3) = IUNIFI('RESULTAT')
C
C     REDIRECTION DES MESSAGES D'ERREUR F
C
      NBUNIT(2) = 3
      UNIT(2,1) = IUNIFI('ERREUR')
      UNIT(2,2) = IUNIFI('MESSAGE')
      UNIT(2,3) = IUNIFI('RESULTAT')
C
C     REDIRECTION DES MESSAGES D'INFORMATION I
C
      NBUNIT(3) = 1
      UNIT(3,1) = IUNIFI('MESSAGE')
C
C     REDIRECTION DES MESSAGES DE DEBUG D
C
      NBUNIT(4) = 1
      UNIT(4,1) = IUNIFI('VIGILE')
C
C     REDIRECTION DES MESSAGES D'ALARME A
C
      NBUNIT(5) = NBFICA
      UNIT(5,1) = IUNIFI('MESSAGE')
      UNIT(5,2) = IUNIFI('RESULTAT')
C
C     REDIRECTION DES MESSAGES D'ERREUR S
C
      NBUNIT(6) = 3
      UNIT(6,1) = IUNIFI('ERREUR')
      UNIT(6,2) = IUNIFI('MESSAGE')
      UNIT(6,3) = IUNIFI('RESULTAT')
C
C     REDIRECTION DES MESSAGES D'IMPRESSION X
C
C     PAR UN APPEL A:  UTRINI( CUNIT )
C
C     --- ELIMINATION DES DOUBLES ---
      DO 10 K = 1, MXUNIT
         DO 20 I = 1, NBUNIT(K)
            DO 30 J = I+1, NBUNIT(K)
               IF ( UNIT(K,I) .EQ. UNIT(K,J) ) UNIT(K,J) = 0
 30         CONTINUE
 20      CONTINUE
 10   CONTINUE
C
C     --- ON COMPACTIFIE LES INFORMATIONS ---
      DO 40 K = 1, MXUNIT
         NB = 0
         DO 50 I = 1, NBUNIT(K)
            IF ( UNIT(K,I) .GT. 0 ) THEN
               NB  = NB + 1
               UNIT(K,NB) = UNIT(K,I)
            ENDIF
 50      CONTINUE
         NBUNIT(K) = NB
 40   CONTINUE
C
      MXCOLS = MCOL
      ITABU  = ITB
      IDF    = 0
      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/utilifor/utinit.f <==
      SUBROUTINE UTINIT ( NBFICA , MCOL , ITB )
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF UTILIFOR  DATE 11/05/2005   AUTEUR MCOURTOI M.COURTOIS 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR   
C (AT YOUR OPTION) ANY LATER VERSION.                                 
C
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT 
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF          
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU    
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                            
C
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE   
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,       
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.      
C ======================================================================
      IMPLICIT REAL*8 (A-H,O-Z)
      INTEGER             NBFICA , MCOL , ITB
C
      INTEGER          MXUNIT     , MXNUML
      PARAMETER      ( MXUNIT = 8 , MXNUML = 4 )
      INTEGER          UNIT(MXUNIT,MXNUML), NBUNIT(MXUNIT)
      COMMON /UTINIF/  UNIT               , NBUNIT
      INTEGER          MXCOLS , ITABU , LIGCOU , COLCOU , IDF
      COMMON /UTINIP/  MXCOLS , ITABU , LIGCOU , COLCOU , IDF
      INTEGER          LDEB
      COMMON /UTDEB /  LDEB
C     COMPTEUR D'ERREURS POUR POUVOIR ARRETER EN F S'IL N'Y A QUE DES E
      INTEGER          NBERRF,NBERRE
      COMMON /UTNBER/  NBERRF,NBERRE
C     ------------------------------------------------------------------
      DO 100 K = 1,MXUNIT
      NBUNIT(K) = 0
      DO 100 L = 1,MXNUML
      UNIT(K,L) = 0
 100  CONTINUE
      LDEB = 5

      NBERRF=0
      NBERRE=0

C     REDIRECTION DES MESSAGES D'ERREUR E
C
      NBUNIT(1) = 3
      UNIT(1,1) = IUNIFI('ERREUR')
      UNIT(1,2) = IUNIFI('MESSAGE')
      UNIT(1,3) = IUNIFI('RESULTAT')
C
C     REDIRECTION DES MESSAGES D'ERREUR F
C
      NBUNIT(2) = 3
      UNIT(2,1) = IUNIFI('ERREUR')
      UNIT(2,2) = IUNIFI('MESSAGE')
      UNIT(2,3) = IUNIFI('RESULTAT')
C
C     REDIRECTION DES MESSAGES D'INFORMATION I
C
      NBUNIT(3) = 1
      UNIT(3,1) = IUNIFI('MESSAGE')
C
C     REDIRECTION DES MESSAGES DE DEBUG D
C
      NBUNIT(4) = 1
      UNIT(4,1) = IUNIFI('VIGILE')
C
C     REDIRECTION DES MESSAGES D'ALARME A
C
      NBUNIT(5) = NBFICA
      UNIT(5,1) = IUNIFI('MESSAGE')
      UNIT(5,2) = IUNIFI('RESULTAT')
C
C     REDIRECTION DES MESSAGES D'ERREUR S ET EXCEPTIONS
C
      NBUNIT(6) = 3
      UNIT(6,1) = IUNIFI('ERREUR')
      UNIT(6,2) = IUNIFI('MESSAGE')
      UNIT(6,3) = IUNIFI('RESULTAT')
C
      NBUNIT(8) = 3
      UNIT(8,1) = IUNIFI('ERREUR')
      UNIT(8,2) = IUNIFI('MESSAGE')
      UNIT(8,3) = IUNIFI('RESULTAT')
C
C     REDIRECTION DES MESSAGES D'IMPRESSION X
C
C     PAR UN APPEL A:  UTRINI( CUNIT )
C
C     --- ELIMINATION DES DOUBLES ---
      DO 10 K = 1, MXUNIT
         DO 20 I = 1, NBUNIT(K)
            DO 30 J = I+1, NBUNIT(K)
               IF ( UNIT(K,I) .EQ. UNIT(K,J) ) UNIT(K,J) = 0
 30         CONTINUE
 20      CONTINUE
 10   CONTINUE
C
C     --- ON COMPACTIFIE LES INFORMATIONS ---
      DO 40 K = 1, MXUNIT
         NB = 0
         DO 50 I = 1, NBUNIT(K)
            IF ( UNIT(K,I) .GT. 0 ) THEN
               NB  = NB + 1
               UNIT(K,NB) = UNIT(K,I)
            ENDIF
 50      CONTINUE
         NBUNIT(K) = NB
 40   CONTINUE
C
      MXCOLS = MCOL
      ITABU  = ITB
      IDF    = 0
      END
